import 'dart:io';

import 'package:path/path.dart' as path;

///  Find the path to the file given a name
///  [fileName] : file name
///  [baseDir] : optional, base directory to the file, if not informed, get current script path.
///  References
///  ----------
///  .. [1] "how to get the file if i know the root directory and relative path". https://stackoverflow.com/questions/22149085/how-to-get-the-file-if-i-know-the-root-directory-and-relative-path/. Retrieved 2019-07-26.
String retrieveFilePath(String fileName, [String baseDir]) {
  var context;
  // get platform context
  if (Platform.isWindows) {
    context = path.Context(style: path.Style.windows);
  } else {
    context = path.Context(style: path.Style.posix);
  }

  // case baseDir not informed, get current script dir
  baseDir ??= path.dirname(Platform.script.path);
  // join dirPath with fileName
  var filePath = context.join(baseDir, fileName);
  // convert Uri to String to make the string treatment more easy
  filePath = context.fromUri(context.normalize(filePath));
  // remove possibles extra paths generated by testing routines context
  filePath = path.fromUri(filePath).split('file:').last;

  return filePath;
}
